==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Depolama mevcut değil",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen hata",
    "Could not move %s - File with this name already exists" : "%s taşınamadı. Bu isimde dosya zaten mevcut",
    "Could not move %s" : "%s taşınamadı",
    "Permission denied" : "Erişim reddedildi",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "\"%s\" is an invalid file name." : "\"%s\" geçersiz bir dosya adı.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Geçersiz isim. '\\', '/', '<', '>', ':', '\"', '|', '?' ve '*' karakterlerine izin verilmemektedir.",
    "The target folder has been moved or deleted." : "Hedef klasör taşındı veya silindi.",
    "The name %s is already used in the folder %s. Please choose a different name." : "%s ismi zaten %s klasöründe kullanılıyor. Lütfen farklı bir isim seçin.",
    "Not a valid source" : "Geçerli bir kaynak değil",
    "Server is not allowed to open URLs, please check the server configuration" : "Sunucunun adresleri açma izni yok, lütfen sunucu yapılandırmasını denetleyin",
    "The file exceeds your quota by %s" : "Dosya, kotanızı %s aşıyor",
    "Error while downloading %s to %s" : "%s, %s içine indirilirken hata",
    "Error when creating the file" : "Dosya oluşturulurken hata",
    "Folder name cannot be empty." : "Klasör adı boş olamaz.",
    "Error when creating the folder" : "Klasör oluşturulurken hata",
    "Unable to set upload directory." : "Yükleme dizini ayarlanamadı.",
    "Invalid Token" : "Geçersiz Belirteç",
    "No file was uploaded. Unknown error" : "Dosya yüklenmedi. Bilinmeyen hata",
    "There is no error, the file uploaded with success" : "Dosya başarıyla yüklendi, hata oluşmadı",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "php.ini dosyasında upload_max_filesize ile belirtilen dosya yükleme sınırı aşıldı:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenecek dosyanın boyutu HTML formunda belirtilen MAX_FILE_SIZE limitini aşıyor",
    "The uploaded file was only partially uploaded" : "Dosya karşıya kısmen yüklenebildi",
    "No file was uploaded" : "Hiç dosya gönderilmedi",
    "Missing a temporary folder" : "Geçici bir dizin eksik",
    "Failed to write to disk" : "Diske yazılamadı",
    "Not enough storage available" : "Yeterli disk alanı yok",
    "Upload failed. Could not find uploaded file" : "Yükleme başarısız. Yüklenen dosya bulunamadı",
    "Upload failed. Could not get file info." : "Yükleme başarısız. Dosya bilgisi alınamadı.",
    "Invalid directory." : "Geçersiz dizin.",
    "Files" : "Dosyalar",
    "All files" : "Tüm dosyalar",
    "Favorites" : "Sık kullanılanlar",
    "Home" : "Ev",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
    "Total file size {size1} exceeds upload limit {size2}" : "Toplam dosya boyutu {size1}, {size2} gönderme sınırını aşıyor",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Could not get result from server." : "Sunucudan sonuç alınamadı.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
    "URL cannot be empty" : "URL boş olamaz",
    "{new_name} already exists" : "{new_name} zaten mevcut",
    "Could not create file" : "Dosya oluşturulamadı",
    "Could not create folder" : "Klasör oluşturulamadı",
    "Error fetching URL" : "Adres getirilirken hata",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşmayı Kaldır",
    "Download" : "İndir",
    "Select" : "Seç",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih tespit edilemedi",
    "Error moving file." : "Dosya taşıma hatası.",
    "Error moving file" : "Dosya taşıma hatası",
    "Error" : "Hata",
    "Could not rename file" : "Dosya adlandırılamadı",
    "Error deleting file." : "Dosya silinirken hata.",
    "No entries in this folder match '{filter}'" : "Bu klasörde hiçbir girdi '{filter}' ile eşleşmiyor",
    "Name" : "İsim",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n dizin","%n dizin"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya oluşturma izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "Your storage is full, files can not be updated or synced anymore!" : "Depolama alanınız dolu, artık dosyalar güncellenmeyecek veya eşitlenmeyecek.",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depolama alanınız neredeyse dolu (%{usedSpacePercent})",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Şifreleme Uygulaması etkin ancak anahtarlarınız başlatılmamış. Lütfen oturumu kapatıp yeniden açın",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Şifreleme Uygulaması için geçersiz özel anahtar. Lütfen şifreli dosyalarınıza erişimi tekrar kazanabilmek için kişisel ayarlarınızdan özel anahtar parolanızı güncelleyin.",
    "Encryption was disabled but your files are still encrypted. Please go to your personal settings to decrypt your files." : "Şifreleme işlemi durduruldu ancak dosyalarınız hala şifreli. Dosyalarınızın şifrelemesini kaldırmak için lütfen kişisel ayarlar kısmına geçin.",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşiyor","'{filter}' ile eşleşiyor"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılan",
    "%s could not be renamed as it has been deleted" : "%s, silindiği için adlandırılamadı",
    "%s could not be renamed" : "%s yeniden adlandırılamadı",
    "Upload (max. %s)" : "Yükle (azami: %s)",
    "File handling" : "Dosya işlemleri",
    "Maximum upload size" : "Azami yükleme boyutu",
    "max. possible: " : "mümkün olan en fazla: ",
    "Save" : "Kaydet",
    "Settings" : "Ayarlar",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\">Dosyalarınıza WebDAV aracılığıyla erişmek için</a> bu adresi kullanın",
    "New" : "Yeni",
    "New text file" : "Yeni metin dosyası",
    "Text file" : "Metin dosyası",
    "New folder" : "Yeni klasör",
    "Folder" : "Klasör",
    "From link" : "Bağlantıdan",
    "Upload" : "Yükle",
    "Cancel upload" : "Yüklemeyi iptal et",
    "No files yet" : "Henüz dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin veya aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucudaki azami yükleme boyutunu aşıyor.",
    "Files are being scanned, please wait." : "Dosyalar taranıyor, lütfen bekleyin.",
    "Currently scanning" : "Şu anda taranan",
    "No favorites" : "Sık kullanılan öge yok.",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılan olarak işaretlediğiniz dosya ve klasörler burada gösterilecek"
},
"nplurals=2; plural=(n > 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Depolama mevcut değil",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen hata",
    "Could not move %s - File with this name already exists" : "%s taşınamadı. Bu isimde dosya zaten mevcut",
    "Could not move %s" : "%s taşınamadı",
    "Permission denied" : "Erişim reddedildi",
    "The target folder has been moved or deleted." : "Hedef klasör taşındı veya silindi.",
    "The name %s is already used in the folder %s. Please choose a different name." : "%s ismi zaten %s klasöründe kullanılıyor. Lütfen farklı bir isim seçin.",
    "Error when creating the file" : "Dosya oluşturulurken hata",
    "Error when creating the folder" : "Klasör oluşturulurken hata",
    "Unable to set upload directory." : "Yükleme dizini ayarlanamadı.",
    "Invalid Token" : "Geçersiz Belirteç",
    "No file was uploaded. Unknown error" : "Dosya yüklenmedi. Bilinmeyen hata",
    "There is no error, the file uploaded with success" : "Dosya başarıyla yüklendi, hata oluşmadı",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "php.ini dosyasında upload_max_filesize ile belirtilen dosya yükleme sınırı aşıldı:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenecek dosyanın boyutu HTML formunda belirtilen MAX_FILE_SIZE limitini aşıyor",
    "The uploaded file was only partially uploaded" : "Dosya karşıya kısmen yüklenebildi",
    "No file was uploaded" : "Hiç dosya gönderilmedi",
    "Missing a temporary folder" : "Geçici bir dizin eksik",
    "Failed to write to disk" : "Diske yazılamadı",
    "Not enough storage available" : "Yeterli disk alanı yok",
    "Upload failed. Could not find uploaded file" : "Yükleme başarısız. Yüklenen dosya bulunamadı",
    "Upload failed. Could not get file info." : "Yükleme başarısız. Dosya bilgisi alınamadı.",
    "Invalid directory." : "Geçersiz dizin.",
    "Files" : "Dosyalar",
    "All files" : "Tüm dosyalar",
    "Favorites" : "Sık kullanılanlar",
    "Home" : "Ev",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
    "Total file size {size1} exceeds upload limit {size2}" : "Toplam dosya boyutu {size1}, {size2} gönderme sınırını aşıyor",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "Could not get result from server." : "Sunucudan sonuç alınamadı.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
    "{new_name} already exists" : "{new_name} zaten mevcut",
    "Could not create file" : "Dosya oluşturulamadı",
    "Could not create folder" : "Klasör oluşturulamadı",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşmayı Kaldır",
    "No permission to delete" : "Silmeye izin yok",
    "Download" : "İndir",
    "Select" : "Seç",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih tespit edilemedi",
    "Error moving file." : "Dosya taşıma hatası.",
    "Error moving file" : "Dosya taşıma hatası",
    "Error" : "Hata",
    "Could not rename file" : "Dosya adlandırılamadı",
    "Error deleting file." : "Dosya silinirken hata.",
    "No entries in this folder match '{filter}'" : "Bu klasörde hiçbir girdi '{filter}' ile eşleşmiyor",
    "Name" : "İsim",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya oluşturma izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} depolama alanı dolu, artık dosyalar güncellenmeyecek yada eşitlenmeyecek.",
    "Your storage is full, files can not be updated or synced anymore!" : "Depolama alanınız dolu, artık dosyalar güncellenmeyecek veya eşitlenmeyecek.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : " {owner} depolama alanı neredeyse dolu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depolama alanınız neredeyse dolu (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşiyor","'{filter}' ile eşleşiyor"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılan",
    "An error occurred while trying to update the tags" : "Etiketler güncellenmeye çalışılırken bir hata oluştu",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya veya klasör <strong>oluşturuldu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya veya klasör <strong>değiştirildi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınızın</strong> oluşturulma ve değiştirilme hakkındaki bildirimlerini sınırla <em>(Sadece akışta)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya veya klasör <strong>silindi</strong>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya veya klasör <strong>geri alındı</strong>",
    "You created %1$s" : "%1$s dosyasını oluşturdunuz",
    "%2$s created %1$s" : "%2$s, %1$s dosyasını oluşturdu",
    "%1$s was created in a public folder" : "%1$s herkese açık klasörde oluşturuldu",
    "You changed %1$s" : "%1$s dosyasını değiştirdiniz",
    "%2$s changed %1$s" : "%2$s, %1$s dosyasını değiştirdi",
    "You deleted %1$s" : "%1$s dosyasını sildiniz",
    "%2$s deleted %1$s" : "%2$s, %1$s dosyasını sildi",
    "You restored %1$s" : "%1$s ögesini geri aldınız",
    "%2$s restored %1$s" : "%2$s, %1$s ögesini geri aldı",
    "%s could not be renamed as it has been deleted" : "%s, silindiği için adlandırılamadı",
    "%s could not be renamed" : "%s yeniden adlandırılamadı",
    "Upload (max. %s)" : "Yükle (azami: %s)",
    "File handling" : "Dosya işlemleri",
    "Maximum upload size" : "Azami yükleme boyutu",
    "max. possible: " : "mümkün olan en fazla: ",
    "Save" : "Kaydet",
    "Can not be edited from here due to insufficient permissions." : "Yetersiz izinler buradan düzenlenemez.",
    "Settings" : "Ayarlar",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "<a href=\"%s\" target=\"_blank\">Dosyalarınıza WebDAV aracılığıyla erişmek için</a> bu adresi kullanın",
    "New" : "Yeni",
    "New text file" : "Yeni metin dosyası",
    "Text file" : "Metin dosyası",
    "New folder" : "Yeni klasör",
    "Folder" : "Klasör",
    "Upload" : "Yükle",
    "Cancel upload" : "Yüklemeyi iptal et",
    "No files in here" : "Burada hiç dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin veya aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucudaki azami yükleme boyutunu aşıyor.",
    "Files are being scanned, please wait." : "Dosyalar taranıyor, lütfen bekleyin.",
    "Currently scanning" : "Şu anda taranan",
    "No favorites" : "Sık kullanılan öge yok.",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılan olarak işaretlediğiniz dosya ve klasörler burada gösterilecek"
},
"nplurals=2; plural=(n > 1);");
